--[[
	Define all Global Variables here
]]

-- Global Variables that are not supposed to be on-the-fly user configurable.
perl_target_locked = 0;
perl_loaded		= 0;
perl_locked		= 1;
perl_init		= 1;  -- This variable is used to tell all the initial function that they can now run.

function Perl_ShowMessage(cMsg)
	local str = "|c00FF7F00"..event.."|r";
	if (arg1) then str = str..", "..arg1; end
	if (arg2) then str = str..", "..arg2; end
	if (arg3) then str = str..", "..arg3; end
	if (arg4) then str = str..", "..arg4; end
	if (arg5) then str = str..", "..arg5; end
	if (arg6) then str = str..", "..arg6; end
	if (arg7) then str = str..", "..arg7; end
	if (arg8) then str = str..", "..arg8; end
	if (arg9) then str = str..", "..arg9; end

	if (cMsg) then
		str = cMsg.." - "..str;
	end

	ChatFrame7:AddMessage("|c00007F7F"..this:GetName().."|r - "..str);
end

function Perl_Globals_OnLoad()
	this:RegisterEvent("VARIABLES_LOADED");
end

local function DefaultVar(name, value)
	if (Perl_Config[name] == nil) then
		Perl_Config[name] = value;
	end
end

function Perl_SetMyGlobal()
	if (Perl_Config_SavePerCharacter) then
		if (not Perl_Config_Global) then
			Perl_Config_Global = {};
		end

		if (not Perl_Config_Global[GetRealmName()]) then
			Perl_Config_Global[GetRealmName()] = {};
		end

		Perl_Config_Global[GetRealmName()][UnitName("player")] = Perl_Config;
	else
		Perl_Config_Global = nil;
	end
end

function Perl_Globals_OnEvent(event)
	-- Between sessions variable saving.
	this:UnregisterEvent(event);

	if (Perl_Config_SavePerCharacter) then
		if (not Perl_Config_Global) then
			Perl_Config_Global = {};
		end

		if (not Perl_Config_Global[GetRealmName()]) then
			Perl_Config_Global[GetRealmName()] = {};
		end

		if (not Perl_Config_Global[GetRealmName()][UnitName("player")]) then
			Perl_Config_Global[GetRealmName()][UnitName("player")] = {};

			if (Perl_Config and table.getn(Perl_Config) > 0) then
				Perl_Config_Global[GetRealmName()][UnitName("player")] = Perl_Config;
			end
		else
			Perl_Config = Perl_Config_Global[GetRealmName()][UnitName("player")];
		end

		if (not Perl_Config) then
			-- Create the global variable
			--Perl_Config = {};
			Perl_Config = Perl_Config_Global[GetRealmName()][UnitName("player")];
		end
	else
		Perl_Config_Global = nil;
		if (not Perl_Config) then
			-- Create the global variable
			Perl_Config = {};
		end
	end

	-- Variable checking only occurs for new install and version number change
	if ((not Perl_Config.ConfigVersion) or (Perl_Config.ConfigVersion ~= Perl_VersionNumber)) then
		Perl_Config.ConfigVersion = Perl_VersionNumber;	-- Set ConfigVersion to current

		DefaultVar("BarTextures",		1);
		DefaultVar("Transparency",		0.8);
		DefaultVar("TextTransparency",		1);
		DefaultVar("BackColour",		{["r"] = 0, ["g"] = 0, ["b"] = 0});
		DefaultVar("BorderColour",		{["r"] = 0.5, ["g"] = 0.5, ["b"] = 0.5});
		DefaultVar("ArcaneBar",			1);
		DefaultVar("OldCastBar",		1);
		DefaultVar("CastTime",			1);
		DefaultVar("ClassColouredNames",	1);
		DefaultVar("HighlightSelection",	1);
		DefaultVar("MinimapButtonPosition",	186);
		DefaultVar("MinimapButtonShown",	1);
		DefaultVar("UseTipBuddy",		1);
		DefaultVar("PerlCombatFlash",		1);
		DefaultVar("PerlFadeFrames",		1);
		DefaultVar("CombatHitIndicator",	1);
		DefaultVar("HighlightDebuffs",		1);
		DefaultVar("HighlightDebuffsBorder",	1);

		DefaultVar("ClassicHealthBar",		1);
		DefaultVar("ColourHealthEmpty",		{r = 1, g = 0, b = 0});
		DefaultVar("ColourHealthFull",		{r = 0, g = 1, b = 0});
		DefaultVar("ColourMana",		{r = 0, g = 0, b = 1});
		DefaultVar("ColourEnergy",		{r = 1, g = 1, b = 0});
		DefaultVar("ColourRage",		{r = 1, g = 0, b = 0});
		DefaultVar("ColourFocus",		{r = 1, g = 0.5, b = 0.25});

		-- Player options
		DefaultVar("ShowPlayerPortrait",	1);
		DefaultVar("ShowPlayerPortrait3D",	1);
		DefaultVar("ShowPlayerLevel",		1);
		DefaultVar("ShowPlayerClassIcon",	1);
		DefaultVar("ShowPlayerXPBar",		0);
		DefaultVar("ShowPlayerPVPRank",		1);
		DefaultVar("ShowOldPlayerFrame",	0);
		DefaultVar("Scale_PlayerFrame",		0.8);
		DefaultVar("ShowPartyNumber",		1);
		DefaultVar("PetHappiness",		1);
		DefaultVar("ShowPetLevel",		1);
		DefaultVar("Scale_PetFrame",		0.8);
		DefaultVar("ShowPetXP",			1);
		DefaultVar("EnergyTicker",		1);

		-- Assist Counters
		DefaultVar("TargetCounters",		1);
		DefaultVar("TargetCountersSelf",	1);
		DefaultVar("TargetCountersEnemy",	1);
		DefaultVar("AssistsFrame",		0);
		DefaultVar("TargettingFrame",		0);
		DefaultVar("Scale_AssistsFrame",	1);
		DefaultVar("AssistsFrame_Transparency", 0.7);

		-- Cast Party
		DefaultVar("CastParty",			1);
		DefaultVar("CastPartyShow",		0);

		-- Raid
		DefaultVar("SortRaidByClass",		0);
		DefaultVar("ShowRaid",			1);
		DefaultVar("ShowGroup1",		1);
		DefaultVar("ShowGroup2",		1);
		DefaultVar("ShowGroup3",		1);
		DefaultVar("ShowGroup4",		1);
		DefaultVar("ShowGroup5",		1);
		DefaultVar("ShowGroup6",		1);
		DefaultVar("ShowGroup7",		1);
		DefaultVar("ShowGroup8",		1);
		DefaultVar("ShowGroup9",		0);
		DefaultVar("ShowGroup1",		1);
		DefaultVar("ShowRaidPercents",		1);
		DefaultVar("Scale_Raid",		0.8);
		DefaultVar("RaidVerticalSpacing",	42);
		DefaultVar("RaidPositions",		{});

		-- Party
		DefaultVar("PartyDebuffsBelow",		0);
		DefaultVar("ShowPartyPets",		1);
		DefaultVar("ShowPartyTarget",		1);
		DefaultVar("ShowPartyLevel",		1);
		DefaultVar("ShowPartyNames",		1);
		DefaultVar("ShowPartyValues",		1);
		DefaultVar("ShowPartyPercent",		1);
		DefaultVar("ShowPartyClassIcon",	1);
		DefaultVar("ShowPartyRaid",		1);
		DefaultVar("PartyBuffs",		1);
		DefaultVar("PartyDebuffs",		1);
		DefaultVar("Scale_PartyFrame",		0.8);
		DefaultVar("TargetTargetHistory",	0);

		-- Target
		DefaultVar("ShowTargetPortrait",	1);
		DefaultVar("ShowTargetClassIcon",	1);
		DefaultVar("ShowTargetMobType",		1);
		DefaultVar("ShowTargetLevel",		1);
		DefaultVar("ShowTargetElite",		1);
		DefaultVar("ShowTargetMana",		1);
		DefaultVar("UseCPMeter",		1);
		DefaultVar("ShowTargetPVPRank",		1);
		DefaultVar("Show30YardSymbol",		1);
		DefaultVar("Scale_TargetFrame",		0.8);
		DefaultVar("AlternateRaidIcon",		1);

		-- Target's Target
		DefaultVar("ShowTargetTarget",		1);
		DefaultVar("TargetTargetBuffs",		1);
		DefaultVar("Scale_TargetTargetFrame",	0.8);

		-- Old vars. clear them out.
		Perl_Config.PerlPlayerPortrait3D = nil;
		Perl_Config.ShowPartyDistance = nil;
		Perl_Config.ShowTargetDistance = nil;
	end

	Perl_Init();
end

-- Perl_InitFadeFrame(argFrame)
function Perl_InitFadeFrame(argFrame)
	argFrame.Fading = 0;
	argFrame.FadeTime = 0;
	argFrame.IsShowing = function () return (argFrame:IsVisible() and argFrame.Fading == 0); end;
end

function Perl_CancelFade(argFrame)
	if (argFrame.Fading == 1) then
		argFrame.Fading = 0;
		argFrame:SetAlpha(Perl_Config.Transparency);
	end
end

-- Perl_StartFade(argFrame)
function Perl_StartFade(argFrame)
	if (Perl_Config.PerlFadeFrames == 1) then
		argFrame:StopMovingOrSizing();

		if (argFrame:IsVisible() and argFrame.Fading == 0) then
			argFrame.Fading = 1;
			argFrame.FadeTime = 0;
		end
	else
		argFrame:Hide();
	end
end

-- Perl_ProcessFade(argFrame)
function Perl_ProcessFade(argFrame)
	if (argFrame.Fading == 1) then
		argFrame.FadeTime = argFrame.FadeTime + arg1;

		if (argFrame.FadeTime >= 1) then
			argFrame:StopMovingOrSizing();
			argFrame:Hide();
			Perl_CancelFade(argFrame);
		else
			local newAlpha = Perl_Config.Transparency * (1 - argFrame.FadeTime);
			argFrame:SetAlpha(newAlpha);
		end
	--else
	--	argFrame:SetAlpha(Perl_Config.Transparency);
	end
end

function Perl_Update_RaidIcon(unit, frame)
	local index = GetRaidTargetIndex(unit);
	if ( index ) then
		SetRaidTargetIconTexture(frame, index);
		frame:Show();
	else
		frame:Hide();
	end
end
